@@ -2,7 +2,7 @@ package App::Reg;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.1.0';
 
 # Return positive value
 1;
@@ -11,29 +11,12 @@ __END__
 
 =head1 NAME
 
-App::Reg - re 'debug' wrapper
-
-=head1 SYNOPSIS
-
-  reg [options] [string] [regex]
-
-  Options:
-    -help            brief help message
-
-=head1 OPTIONS
-
-=over 8
-
-=item B<-help>
-
-Print a brief help message and exits.
-
-=back
+App::Reg - reg RegExp debugger
 
 =head1 DESCRIPTION
 
-B<This program> tries to match regex to string and shows Perl regular
-expression debugger output.
+App::Reg contains the L<reg> RegExp debugger. This module only contains
+its version in global C<$VERSION> variable.
 
 =head1 AUTHOR
 
@@ -42,6 +25,6 @@ Konrad Borowski <glitchmr@myopera.com>
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Konrad Borowski.
- 
+
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
